@@ -131,8 +131,8 @@ static void tangle_apply_template_action_dispose(GObject* object) {
 	
 	action = TANGLE_APPLY_TEMPLATE_ACTION(object);
 	
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(action->priv->template);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(action->priv->object);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(action->priv->template);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(action->priv->object);
 
 	G_OBJECT_CLASS(tangle_apply_template_action_parent_class)->dispose(object);
 }
