@@ -71,9 +71,6 @@ struct _TangleScrollActionPrivate {
 	
 	guint kinetic_scrolling : 1;
 	guint bind_to_scroll_trick : 1;
-
-	guint descendant_interacting : 1;	
-	guint descendant_dragging : 1;
 };
 
 static guint signals[LAST_SIGNAL] = { 0 };
@@ -694,7 +691,7 @@ static void handle_event(TangleScrollAction* scroll_action, ClutterActor* actor,
 	d = coordinate - scroll_action->priv->start_scrolling_motion[axis];
 
 	if (scroll_action->priv->scrolling_effective[axis] ||
-	    (!scroll_action->priv->descendant_dragging &&
+	    (!(TANGLE_IS_WIDGET(actor) && tangle_widget_get_descendant_dragging(TANGLE_WIDGET(actor))) &&
 	     (ABS_F(d) > scroll_action->priv->threshold[axis]))) {
 
 		if (!scroll_action->priv->scrolling_effective[axis] ||
